@@ -1,12 +1,11 @@
 use sysinfo::{ProcessExt, SystemExt};
 
-#[derive(Debug, serde::Serialize, serde::Deserialize)]
+#[derive(Debug, Clone, serde::Serialize, serde::Deserialize)]
 pub struct DiskUsage {
     pub bytes_read: usize,
     pub bytes_written: usize,
 }
 
-#[no_sanitize(memory)]
 pub(crate) fn disk_io_of_func<F: FnOnce() -> R, R>(f: F) -> (DiskUsage, R) {
     // Start our disk counter
     let mut sys_info = sysinfo::System::new();
